@@ -1,9 +1,13 @@
-# Copyright (c) 2021 Apex Resource Management Solution Ltd. (ApexRMS). All rights reserved.
+# Copyright (c) 2023 Apex Resource Management Solution Ltd. (ApexRMS). All rights reserved.
 # MIT License
 #' @include AAAClassDefinitions.R
 NULL
 
 #' Retrieve spatial data from a SyncroSim Datasheet
+#' 
+#' `r lifecycle::badge("deprecated")`
+#'
+#' Please use \code{\link{datasheetSpatRaster}} instead.
 #'
 #' This function retrieves spatial columns from one or more SyncroSim 
 #' \code{\link{Scenario}} Datasheets.
@@ -69,6 +73,7 @@ NULL
 #'                          session = mySession,
 #'                          package = "helloworldSpatial",
 #'                          template = "example-library",
+#'                          forceUpdate = TRUE,
 #'                          overwrite=TRUE)
 #' 
 #' # Set up Project and Scenario
@@ -119,7 +124,8 @@ NULL
 #' myLibrary <- ssimLibrary(name = myLibraryName,
 #'                          session = mySession, 
 #'                          package = "stsim",
-#'                          template = "spatial-example")
+#'                          template = "spatial-example",
+#'                          forceUpdate = TRUE)
 #'                          
 #' myScenario <- scenario(myLibrary, scenario = 16)
 #' 
@@ -140,11 +146,13 @@ setGeneric("datasheetRaster", function(ssimObject, datasheet, column = NULL, sce
 
 #' @rdname datasheetRaster
 setMethod("datasheetRaster", signature(ssimObject = "character"), function(ssimObject, datasheet, column, scenario, iteration, timestep, filterColumn, filterValue, subset, forceElements, pathOnly) {
+  lifecycle::deprecate_warn("1.4.6", "datasheetRaster()", "datasheetSpatRaster()")
   return(SyncroSimNotFound(ssimObject))
 })
 
 #' @rdname datasheetRaster
 setMethod("datasheetRaster", signature(ssimObject = "list"), function(ssimObject, datasheet, column, scenario, iteration, timestep, filterColumn, filterValue, subset, forceElements, pathOnly) {
+  lifecycle::deprecate_warn("1.4.6", "datasheetRaster()", "datasheetSpatRaster()")
   if (!is(ssimObject[[1]], "Scenario")) {
     stop("Expecting an SsimLibrary/Project/Scenario or list of Scenario objects.")
   }
@@ -175,6 +183,7 @@ setMethod("datasheetRaster", signature(ssimObject = "list"), function(ssimObject
 
 #' @rdname datasheetRaster
 setMethod("datasheetRaster", signature(ssimObject = "SsimObject"), function(ssimObject, datasheet, column, scenario, iteration, timestep, filterColumn, filterValue, subset, forceElements, pathOnly) {
+  lifecycle::deprecate_warn("1.4.6", "datasheetRaster()", "datasheetSpatRaster()")
   if (is.null(scenario)) {
     stop("If ssimObject is an SimLibrary or Project, one or more scenarios must be specified using the scenario argument.")
   }
@@ -198,6 +207,7 @@ setMethod("datasheetRaster", signature(ssimObject = "SsimObject"), function(ssim
 
 #' @rdname datasheetRaster
 setMethod("datasheetRaster", signature(ssimObject = "Scenario"), function(ssimObject, datasheet, column, scenario, iteration, timestep, filterColumn, filterValue, subset, forceElements, pathOnly) {
+  lifecycle::deprecate_warn("1.4.6", "datasheetRaster()", "datasheetSpatRaster()")
   rat <- NULL
   if (is.null(subset)) {
     getFactors <- FALSE
