@@ -1,22 +1,22 @@
-# Copyright (c) 2021 Apex Resource Management Solution Ltd. (ApexRMS). All rights reserved.
+# Copyright (c) 2023 Apex Resource Management Solution Ltd. (ApexRMS). All rights reserved.
 # MIT License
 #' @include AAAClassDefinitions.R
 NULL
 
 #' Description of SsimLibrary, Project or Scenario
 #'
-#' Get or set the description of a \code{\link{SsimLibrary}}, \code{\link{Project}} or 
-#' \code{\link{Scenario}}.
+#' Get or set the description of a \code{\link{SsimLibrary}}, \code{\link{Project}}, 
+#' \code{\link{Scenario}} or \code{\link{Folder}}.
 #'
-#' @param ssimObject \code{\link{SsimLibrary}}, \code{\link{Project}} or 
-#' \code{\link{Scenario}} object
+#' @param ssimObject \code{\link{SsimLibrary}}, \code{\link{Project}}, 
+#' \code{\link{Scenario}}, or \code{\link{Folder}} object
 #' @param value character string specifying the new description
 #' 
 #' @return
 #' A character string: the description of the SsimObject
 #' 
 #' @examples 
-#' \donttest{
+#' \dontrun{
 #' # Specify file path and name of new SsimLibrary
 #' myLibraryName <- file.path(tempdir(), "testlib")
 #' 
@@ -67,6 +67,24 @@ setMethod("description", signature(ssimObject = "SsimObject"), function(ssimObje
   return(desc)
 })
 
+#' @rdname description
+setMethod("description", signature(ssimObject = "Folder"), function(ssimObject) {
+  
+  desc <- command(list(list = NULL, description = NULL, 
+                       lib = .filepath(ssimObject), 
+                       fid = .folderId(ssimObject)), 
+                  session = .session(ssimObject))
+
+  while (max(grepl("  ", desc, fixed = TRUE))) {
+    desc <- gsub("  ", " ", desc, fixed = TRUE)
+  }
+  desc <- gsub(". ", ".", desc, fixed = TRUE)
+  
+  desc <- desc[2:length(desc)]
+  
+  return(desc)
+})
+
 #' @rdname description
 setReplaceMethod(
   f = "description",
@@ -103,3 +121,26 @@ setReplaceMethod(
     return(ssimObject)
   }
 )
+
+#' @rdname description
+setReplaceMethod(
+  f = "description",
+  signature = "Folder",
+  definition = function(ssimObject, value) {
+    inValue <- value
+    if (length(inValue) > 1) {
+      value <- ""
+      for (i in 1:length(inValue)) {
+        value <- paste0(value, inValue[[i]], sep = "\n")
+      }
+    }
+    value <- gsub("\n", "\\n", value, fixed = TRUE)
+    args <- list(setprop = NULL, lib = .filepath(ssimObject), 
+                 description = value, fid = .folderId(ssimObject))
+    tt <- command(args, .session(ssimObject))
+    if (!identical(tt, "saved")) {
+      stop(tt)
+    }
+    return(ssimObject)
+  }
+)
