@@ -1,15 +1,15 @@
-# Copyright (c) 2021 Apex Resource Management Solution Ltd. (ApexRMS). All rights reserved.
+# Copyright (c) 2023 Apex Resource Management Solution Ltd. (ApexRMS). All rights reserved.
 # MIT License
 #' @include AAAClassDefinitions.R
 NULL
 
-#' Owner of a SsimLibrary, Project or Scenario
+#' Owner of a SsimLibrary, Project, Scenario, or Folder
 #'
 #' Retrieves or sets the owner of a \code{\link{SsimLibrary}},
-#' \code{\link{Project}} or \code{\link{Scenario}}.
+#' \code{\link{Project}}, \code{\link{Scenario}}, or \code{\link{Folder}}.
 #'
 #' @param ssimObject \code{\link{Session}}, \code{\link{Project}}, 
-#' or \code{\link{SsimLibrary}} object
+#' \code{\link{SsimLibrary}}, or \code{\link{Folder}} object
 #' @param value character string of the new owner
 #' 
 #' @return 
@@ -56,8 +56,8 @@ setMethod("owner", signature(ssimObject = "SsimLibrary"), function(ssimObject) {
 
 #' @rdname owner
 setMethod("owner", signature(ssimObject = "Project"), function(ssimObject) {
-  scnInfo <- project(ssimObject, summary = TRUE)
-  return(scnInfo$owner)
+  projInfo <- project(ssimObject, summary = TRUE)
+  return(projInfo$owner)
 })
 
 #' @rdname owner
@@ -66,6 +66,12 @@ setMethod("owner", signature(ssimObject = "Scenario"), function(ssimObject) {
   return(scnInfo$owner)
 })
 
+#' @rdname owner
+setMethod("owner", signature(ssimObject = "Folder"), function(ssimObject) {
+  info <- getFolderData(ssimObject)
+  return(info$Owner)
+})
+
 #' @rdname owner
 setReplaceMethod(
   f = "owner",
@@ -94,3 +100,18 @@ setReplaceMethod(
     return(ssimObject)
   }
 )
+
+#' @rdname owner
+setReplaceMethod(
+  f = "owner",
+  signature = "Folder",
+  definition = function(ssimObject, value) {
+    args <- list(setprop = NULL, lib = .filepath(ssimObject), owner = value, 
+                 fid = .folderId(ssimObject))
+    tt <- command(args, .session(ssimObject))
+    if (!identical(tt, "saved")) {
+      stop(tt)
+    }
+    return(ssimObject)
+  }
+)
