@@ -1,4 +1,4 @@
-# Copyright (c) 2021 Apex Resource Management Solution Ltd. (ApexRMS). All rights reserved.
+# Copyright (c) 2023 Apex Resource Management Solution Ltd. (ApexRMS). All rights reserved.
 # MIT License
 #' @include AAAClassDefinitions.R
 NULL
@@ -6,12 +6,12 @@ NULL
 # @importFrom utils packageVersion
 # @name Session
 # @rdname Session-class
-setMethod(f = "initialize", signature = "Session", definition = function(.Object, path, silent = FALSE, printCmd = FALSE, condaFilepath = NULL) {
+setMethod(f = "initialize", signature = "Session", definition = function(.Object, path, silent = FALSE, printCmd = FALSE) {
   
   .Object@filepath <- gsub("\\", "/", gsub("/SyncroSim.Console.exe", "", path, fixed = TRUE), fixed = TRUE)
   .Object@silent <- silent
   .Object@printCmd <- printCmd
-  .Object@condaFilepath <- condaFilepath
+  .Object@condaFilepath <- NULL
 
   ssimRequiredVersion <- "2.3.24"
   ssimCurrentVersion <- command(list(version = NULL), .Object)
@@ -63,10 +63,6 @@ setMethod(f = "initialize", signature = "Session", definition = function(.Object
 #' @param printCmd logical. Applies only if x is a path or \code{NULL} If \code{TRUE}, 
 #'     arguments passed to the SyncroSim console are also printed. Helpful for 
 #'     debugging. Default is \code{FALSE}
-#' @param condaFilepath string. Gets or sets the path to the
-#'     Conda installation folder. Can be used to direct SyncroSim to a custom
-#'     Conda installation. If \code{"default"} (default), then default Conda 
-#'     installation folder is used
 #' @param ssimObject \code{\link{Project}} or \code{\link{Scenario}} object
 #' @param value \code{\link{Session}} object
 #' 
@@ -84,7 +80,7 @@ setMethod(f = "initialize", signature = "Session", definition = function(.Object
 #' A SyncroSim \code{\link{Session}} object.
 #' 
 #' @examples
-#' \donttest{
+#' \dontrun{
 #' # Specify file path and name of new SsimLibrary
 #' myLibraryName <- file.path(tempdir(), "testlib")
 #' 
@@ -110,10 +106,10 @@ setMethod(f = "initialize", signature = "Session", definition = function(.Object
 #' }
 #' 
 #' @export
-setGeneric("session", function(x = NULL, silent = TRUE, printCmd = FALSE, condaFilepath = NULL) standardGeneric("session"))
+setGeneric("session", function(x = NULL, silent = TRUE, printCmd = FALSE) standardGeneric("session"))
 
 #' @rdname session
-setMethod("session", signature(x = "missingOrNULLOrChar"), function(x, silent, printCmd, condaFilepath) {
+setMethod("session", signature(x = "missingOrNULLOrChar"), function(x, silent, printCmd) {
   path <- x
   
   if (!is.null(path)) {
@@ -170,21 +166,15 @@ setMethod("session", signature(x = "missingOrNULLOrChar"), function(x, silent, p
   } else {
     progName <- path
   }
-  if (is.null(condaFilepath)) {
-    tt <- command(args = list(conda = NULL, clear = NULL), progName = progName)
-  } else {
-    tt <- command(args = list(conda = NULL, path = condaFilepath), progName = progName)
-    if (startsWith(tt[1], "The folder does not contain a valid Conda executable")) {
-      message(tt[1])
-      condaFilepath <- "default"
-    }
-  }
 
-  return(new("Session", path, silent, printCmd, condaFilepath))
+  return(new("Session", path, silent, printCmd))
 })
 
 #' @rdname session
-setMethod("session", signature(x = "SsimObject"), function(x, silent, printCmd, condaFilepath) x@session)
+setMethod("session", signature(x = "SsimObject"), function(x, silent, printCmd) x@session)
+
+#' @rdname session
+setMethod("session", signature(x = "Folder"), function(x, silent, printCmd) x@session)
 
 #' @rdname session
 #' @export
